@@ -1,10 +1,10 @@
-import term
+"""Packaging tools for the terminal."""
 
-import pkg
-import pkg.discover
-import pkg.install
-import pkg.licensing
-import pkg.listing
+import sh
+
+from understory import term
+
+from .. import pkg
 
 
 main = term.application("pkg", pkg.__doc__)
@@ -15,6 +15,30 @@ def complete_distname(prefix, **kwargs):
             if dist.startswith(prefix))
 
 
+@main.register()
+class Publish:
+    """Publish a release to PyPI and GitHub."""
+
+    def setup(self, add_arg):
+        add_arg("rule", choices=["patch", "minor", "major"],
+                help="increment to bump the version")
+
+    def run(self, stdin, log):
+        try:
+            sh.poetry("run", "pytest")
+        except sh.ErrorReturnCode_5:
+            pass
+        sh.poetry("version", self.rule)
+        sh.poetry("build")
+        sh.poetry("publish")
+        sh.git("commit", "-a", "-m", "Bump version in pyproject.toml")
+        sh.git("push")
+        sh.gh("release", "create", sh.poetry("version", "-s"),
+              sh.tail("-n1", sh.grep(".whl", sh.ls("-tr", "dist"))))
+        sh.git("pull")
+        return 0
+
+
 @main.register()
 class List:
 
